@@ -13,7 +13,7 @@ const TRANSFORMER_FACTORY = 'transformer';
 
 let isTransformerEnabled: boolean = true;
 const updateTransformerEnabled = (settings: ISettingRegistry.ISettings): void => {
-    isTransformerEnabled = getTransformerEnabled(settings);
+    isTransformerEnabled = getTransformerEnabled();
 };
 
 let isTransformerNotebook: boolean = false;
@@ -43,7 +43,7 @@ export default {
     ) => {
         Promise.all([settingRegistry.load(SETTINGS_ID)]).then(([settings]) => {
             settings.changed.connect(updateTransformerEnabled);
-            isTransformerEnabled = getTransformerEnabled(settings);
+            isTransformerEnabled = getTransformerEnabled();
         });
 
         if(notebookTracker) {
